@@ -5,12 +5,18 @@ import logging
 from alephclient import settings
 from alephclient.api import AlephAPI
 from alephclient.errors import AlephException
-from alephclient.tasks.crawldir import crawl_dir
-from alephclient.tasks.bulkload import bulk_load
+from alephclient.crawldir import crawl_dir
 
 log = logging.getLogger(__name__)
 
 
+def _get_id_from_foreign_key(api, foreign_id):
+    collection = api.get_collection_by_foreign_id(foreign_id)
+    if collection is None:
+        raise click.ClickException("Collection does not exist.")
+    return collection.get('id')
+
+
 @click.group()
 @click.option('--host', default=settings.HOST, metavar="HOST", help="Aleph API host URL")  # noqa
 @click.option('--api-key', default=settings.API_KEY, metavar="KEY", help="Aleph API key for authentication")  # noqa
@@ -31,11 +37,13 @@ def cli(ctx, host, api_key, retries):
 
 @cli.command()
 @click.option('--casefile', is_flag=True, default=False, help='handle as case file')  # noqa
+@click.option('-i', '--noindex', is_flag=True, default=False, help='do not index documents after ingest')  # noqa
 @click.option('-l', '--language', multiple=True, help="language hint: 2-letter language code (ISO 639)")  # noqa
 @click.option('-f', '--foreign-id', required=True, help="foreign_id of the collection")  # noqa
 @click.argument('path', type=click.Path(exists=True))
 @click.pass_context
-def crawldir(ctx, path, foreign_id, language=None, casefile=False):
+def crawldir(ctx, path, foreign_id, language=None,
+             casefile=False, noindex=False):
     """Crawl a directory recursively and upload the documents in it to a
     collection."""
     try:
@@ -44,21 +52,65 @@ def crawldir(ctx, path, foreign_id, language=None, casefile=False):
             'casefile': casefile
         }
         api = ctx.obj["api"]
-        crawl_dir(api, path, foreign_id, config)
+        crawl_dir(api, path, foreign_id, config, index=not noindex)
     except AlephException as exc:
         raise click.ClickException(str(exc))
 
 
-@cli.command()
-@click.argument('mapping_file')
+@cli.command('reingest')
+@click.option('-f', '--foreign-id', required=True, help="foreign_id of the collection")  # noqa
+@click.option('--index', is_flag=True, default=False, help="index documents as they are being processed")  # noqa
 @click.pass_context
-def bulkload(ctx, mapping_file):
-    """Trigger a load of structured entity data using the submitted mapping."""
-    # TODO: When can we remove this?
+def reingest_collection(ctx, foreign_id, index=False):
+    """Trigger a re-ingest on all the documents in the collection."""
+    api = ctx.obj["api"]
     try:
-        bulk_load(ctx.obj["api"], mapping_file)
+        collection_id = _get_id_from_foreign_key(api, foreign_id)
+        api.regingest_collection(collection_id, index=index)
     except AlephException as exc:
-        raise click.ClickException(str(exc))
+        raise click.ClickException(exc.message)
+
+
+@cli.command('reindex')
+@click.option('-f', '--foreign-id', required=True, help="foreign_id of the collection")  # noqa
+@click.option('--flush', is_flag=True, default=False, help="flush entities before indexing")  # noqa
+@click.pass_context
+def reindex_collection(ctx, foreign_id, flush=False):
+    """Trigger a re-index of all the entities in the collection."""
+    api = ctx.obj["api"]
+    try:
+        collection_id = _get_id_from_foreign_key(api, foreign_id)
+        api.reindex_collection(collection_id, flush=flush)
+    except AlephException as exc:
+        raise click.ClickException(exc.message)
+
+
+@cli.command('delete')
+@click.option('-f', '--foreign-id', required=True, help="foreign_id of the collection")  # noqa
+@click.option('--sync', is_flag=True, default=False, help="wait for delete to complete")  # noqa
+@click.pass_context
+def delete_collection(ctx, foreign_id, sync=False):
+    """Delete a collection and all its contents."""
+    api = ctx.obj["api"]
+    try:
+        collection_id = _get_id_from_foreign_key(api, foreign_id)
+        api.delete_collection(collection_id, sync=sync)
+    except AlephException as exc:
+        raise click.ClickException(exc.message)
+
+
+@cli.command('flush')
+@click.option('-f', '--foreign-id', required=True, help="foreign_id of the collection")  # noqa
+@click.option('--sync', is_flag=True, default=False, help="wait for delete to complete")  # noqa
+@click.pass_context
+def flush_collection(ctx, foreign_id, sync=False):
+    """Delete a all the contents of a collection."""
+    api = ctx.obj["api"]
+    try:
+        collection_id = _get_id_from_foreign_key(api, foreign_id)
+        api.flush_collection(collection_id, sync=sync)
+    except AlephException as exc:
+        raise click.ClickException(exc.message)
 
 
 @cli.command('write-entities')
@@ -71,8 +123,7 @@ def write_entities(ctx, infile, foreign_id, force=False, unsafe=False):
     """Read entities from standard input and index them."""
     api = ctx.obj["api"]
     try:
-        collection = api.load_collection_by_foreign_id(foreign_id, {})
-        collection_id = collection.get('id')
+        collection_id = _get_id_from_foreign_key(api, foreign_id)
 
         def read_json_stream(stream):
             count = 0
